@@ -7,7 +7,7 @@
 -- |
 --  Module      :  Datatype
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012 Douglas Burke
+--                 2011, 2012, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -71,7 +71,8 @@ import Swish.Utils.ListHelpers (flist)
 --
 -- import Swish.Utils.ShowM (ShowM(..))
 
-import Control.Monad (join, liftM)
+import Control.Applicative ((<$>))
+import Control.Monad (join)
 
 import Data.Maybe (isJust, catMaybes)
 
@@ -252,7 +253,7 @@ tvalMkCanonicalForm dtv str = can
     where
       dtmap = tvalMap dtv
       val   = mapL2V dtmap str
-      can   = join $ liftM (mapV2L dtmap) val
+      can   = join $ fmap (mapV2L dtmap) val
 
 -- |DatatypeMap consists of methods that perform lexical-to-value
 --  and value-to-canonical-lexical mappings for a datatype.
@@ -787,7 +788,7 @@ altArgs pr fnss apfn args = cvals4 cvals3
         cvals2 = sequence $ mergeTupleVals (map fst fnss) args cvals1
         --  Map list of alternative values for each tuple member to
         --  a list of alternative tuples.
-        cvals3 = liftM sequence cvals2
+        cvals3 = fmap sequence cvals2
         --  Check each tuple against the supplied predicate.
         --  If any of the alternative tuples does not match the predicate
         --  then signal an inconsistency.
@@ -821,7 +822,7 @@ applyFdescToTuple ::
     ((vt->Bool)->b->[Maybe vt]->Maybe [vt]) -> (vt->Bool,[b]) -> [Maybe vt]
     -> Maybe [vt]
 applyFdescToTuple apfn (p,fns) args =
-    liftM concat $ sequence cvals
+    concat <$> sequence cvals
     where
         -- cvals :: [Maybe [vt]]
         cvals = flist (map (apfn p) fns) args
@@ -1036,7 +1037,7 @@ data DatatypeSub ex lb vn supvt subvt = DatatypeSub
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012 Douglas Burke
+--    2011, 2012, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
