@@ -7,7 +7,7 @@
 -- |
 --  Module      :  ClassRestrictionRule
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2014 Douglas Burke
+--                 2011, 2012, 2014, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -57,7 +57,7 @@ import Swish.RDF.Query
 import Swish.RDF.VarBinding (RDFVarBinding)
 import Swish.RDF.Vocabulary (namespaceRDFD)
 
-import Control.Monad (liftM)
+import Control.Applicative ((<$>))
 
 import Data.List (delete, nub, subsequences)
 import Data.Maybe (fromJust, fromMaybe, mapMaybe)
@@ -118,7 +118,7 @@ makeDatatypeRestriction dtv dtrel = ClassRestriction
 makeDatatypeRestrictionFn ::
     RDFDatatypeVal vt -> DatatypeRelFn vt -> ClassRestrictionFn
 makeDatatypeRestrictionFn dtv dtrelfn =
-    liftM (mapMaybe toLabels) . dtrelfn . map frLabel
+    fmap (mapMaybe toLabels) . dtrelfn . map frLabel
     where
         frLabel Nothing  = Nothing
         frLabel (Just l) = fromRDFLabel dtv l
@@ -257,7 +257,7 @@ bwdApplyRestriction restriction cls props cs congr =
         --  yielding an equivalent disjunction of conjunctions
         --  map concat flattens the conjunctions of conjuctions
         newgrs :: Maybe [[RDFGraph]]
-        newgrs = liftM (map concat . sequence) $ mapM newgr ris
+        newgrs = map concat . sequence <$> mapM newgr ris
 
 --  Backward apply a class restriction to single class instance (ci).
 --  Return one or more sets of antecedent results from which the consequence
@@ -527,7 +527,7 @@ makeRDFDatatypeRestrictionRules dtval =
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012 Douglas Burke
+--    2011, 2012, 2014, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
