@@ -7,7 +7,7 @@
 -- |
 --  Module      :  Internal
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014, 2016 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2016, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -82,18 +82,12 @@ import Data.Maybe (isJust)
 #if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
 import Data.Monoid (Monoid(..), mconcat)
 #endif
+import Data.Tuple (swap)
 import Data.Word
 
 import Network.URI (URI)
 import Network.URI.Ord ()
 
-#if defined(__GLASGOW_HASKELL__) && (__GLASGOW_HASKELL__ >= 701)
-import Data.Tuple (swap)
-#else
-swap :: (a,b) -> (b,a)
-swap (a,b) = (b,a)
-#endif
-
 findPrefix :: URI -> M.Map a URI -> Maybe a
 findPrefix u = M.lookup u . M.fromList . map swap . M.assocs
 
@@ -709,7 +703,7 @@ extractList_ subjs props setSubjs setProps lctxt ln = do
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013 Douglas Burke
+--    2011, 2012, 2013, 2014, 2016, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
