@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 --------------------------------------------------------------------------------
@@ -5,12 +6,12 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  N3
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  OverloadedStrings
+--  Portability :  CPP, OverloadedStrings
 --
 --  This Module implements a Notation 3 parser, returning a
 --  new 'RDFGraph' consisting of triples and namespace information parsed from
@@ -138,7 +139,12 @@ import Swish.RDF.Parser.Utils
 import Control.Applicative
 import Control.Monad (forM_, foldM)
 
-import Data.Char (isSpace, isDigit, ord, isAsciiLower) 
+import Data.Char (isSpace, isDigit, ord, isAsciiLower)
+
+#if MIN_VERSION_base(4, 7, 0)
+import Data.Functor (($>))
+#endif
+
 import Data.Maybe (fromMaybe, fromJust)
 import Data.Word (Word32)
 
@@ -151,6 +157,11 @@ import qualified Data.Map as M
 import qualified Data.Text as T
 import qualified Data.Text.Lazy as L
 
+#if !MIN_VERSION_base(4, 7, 0)
+($>) :: Functor f => f a -> b -> f b
+($>) = flip (<$)
+#endif
+
 ----------------------------------------------------------------------
 -- Define parser state and helper functions
 ----------------------------------------------------------------------
@@ -547,12 +558,12 @@ not clear whether we need to support this too, so for now we do not.
 -}
 protectedChar :: N3Parser Char
 protectedChar =
-  (char 't' *> return '\t')
-  <|> (char 'n' *> return '\n')
-  <|> (char 'r' *> return '\r')
-  <|> (char '"' *> return '"')
-  <|> (char '\'' *> return '\'')
-  <|> (char '\\' *> return '\\')
+  (char 't' $> '\t')
+  <|> (char 'n' $> '\n')
+  <|> (char 'r' $> '\r')
+  <|> (char '"' $> '"')
+  <|> (char '\'' $> '\'')
+  <|> (char '\\' $> '\\')
   <|> (char 'u' *> hex4)
   <|> (char 'U' *> hex8)
 
@@ -624,14 +635,14 @@ _protChar = char '\\' *> (_echar' <|> _uchar')
 
 _echar' :: N3Parser Char
 _echar' = 
-  (char 't' *> pure '\t') <|>
-  (char 'b' *> pure '\b') <|>
-  (char 'n' *> pure '\n') <|>
-  (char 'r' *> pure '\r') <|>
-  (char 'f' *> pure '\f') <|>
-  (char '\\' *> pure '\\') <|>
-  (char '"' *> pure '"') <|>
-  (char '\'' *> pure '\'')
+  (char 't' $> '\t') <|>
+  (char 'b' $> '\b') <|>
+  (char 'n' $> '\n') <|>
+  (char 'r' $> '\r') <|>
+  (char 'f' $> '\f') <|>
+  (char '\\' $> '\\') <|>
+  (char '"' $> '"') <|>
+  (char '\'' $> '\'')
 
 _uchar' :: N3Parser Char
 _uchar' =
@@ -859,7 +870,7 @@ TODO: fix this?
 
 existential :: N3Parser ()
 -- existential = try (atWord "forSome") *> symbolCsl >> return ()
-existential = atWord "forSome" *> symbolCsl *> pure ()
+existential = (atWord "forSome" *> symbolCsl) $> ()
 
 {-
 simpleStatement ::=		|	subject propertylist
@@ -887,8 +898,8 @@ expression :: N3Parser RDFLabel
 expression = do
   i <- pathItem
   
-  let backwardExpr = char '!' *> return addStatementRev 
-      forwardExpr  = char '^' *> return addStatement
+  let backwardExpr = char '!' $> addStatementRev
+      forwardExpr  = char '^' $> addStatement
   
   mpt <- optional
         ( (,) <$> lexeme (forwardExpr <|> backwardExpr) <*> lexeme expression )
@@ -1222,7 +1233,7 @@ universal =
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013 Douglas Burke
+--    2011, 2012, 2013, 2014, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
