@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 --------------------------------------------------------------------------------
@@ -5,12 +6,12 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Turtle
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018 Douglas Burke
 --  License     :  GPL V2
 -- 
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  OverloadedStrings
+--  Portability :  CPP, OverloadedStrings
 -- 
 --  This Module implements a Turtle parser, returning a
 --  new 'RDFGraph' consisting of triples and namespace information parsed from
@@ -104,6 +105,11 @@ import Control.Applicative
 import Control.Monad (foldM)
 
 import Data.Char (chr, isAsciiLower, isAsciiUpper, isDigit, isHexDigit, ord, toLower)
+
+#if MIN_VERSION_base(4, 7, 0)
+import Data.Functor (($>))
+#endif
+
 import Data.Maybe (fromMaybe)
 import Data.Word (Word32)
 
@@ -116,6 +122,11 @@ import qualified Data.Map as M
 import qualified Data.Text as T
 import qualified Data.Text.Lazy as L
 
+#if !MIN_VERSION_base(4, 7, 0)
+($>) :: Functor f => f a -> b -> f b
+($>) = flip (<$)
+#endif
+
 ----------------------------------------------------------------------
 -- Define parser state and helper functions
 ----------------------------------------------------------------------
@@ -264,7 +275,7 @@ br lsym rsym =
 
 -- this is a lot simpler than N3
 atWord :: T.Text -> TurtleParser ()
-atWord s = char '@' *> lexeme (stringT s) *> pure ()
+atWord s = (char '@' *> lexeme (stringT s)) $> ()
 
 -- | Case insensitive match.
 charI ::
@@ -751,7 +762,7 @@ noTrailingDot = noTrailing (char '.') id
 noTrailingDotM ::
   TurtleParser L.Text -- ^ This *should not* match '.'
   -> TurtleParser L.Text
-noTrailingDotM  = noTrailing (char '.' *> pure ".") (L.unpack . L.concat)
+noTrailingDotM  = noTrailing (char '.' $> ".") (L.unpack . L.concat)
 
 {-
 [144s]	LANGTAG	::=	'@' [a-zA-Z]+ ('-' [a-zA-Z0-9]+)*
@@ -937,14 +948,14 @@ _echar = char '\\' *> _echar'
 
 _echar' :: TurtleParser Char
 _echar' = 
-  (char 't' *> pure '\t') <|>
-  (char 'b' *> pure '\b') <|>
-  (char 'n' *> pure '\n') <|>
-  (char 'r' *> pure '\r') <|>
-  (char 'f' *> pure '\f') <|>
-  (char '\\' *> pure '\\') <|>
-  (char '"' *> pure '"') <|>
-  (char '\'' *> pure '\'')
+  (char 't' $> '\t') <|>
+  (char 'b' $> '\b') <|>
+  (char 'n' $> '\n') <|>
+  (char 'r' $> '\r') <|>
+  (char 'f' $> '\f') <|>
+  (char '\\' $> '\\') <|>
+  (char '"' $> '"') <|>
+  (char '\'' $> '\'')
 
 {-
 [161s]	WS	::=	#x20 | #x9 | #xD | #xA
@@ -1039,7 +1050,7 @@ _pnLocalEscChars = "_~.-!$&'()*+,;=/?#@%"
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013 Douglas Burke
+--    2011, 2012, 2013, 2014, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
